@@ -5,8 +5,7 @@ License - MIT
 
 from PySide2.QtCore import Signal
 
-from app import module_base
-from app import app_common
+from app import module_base, app_common
 from app.app_base import ApplicationBase
 from modules.scan_module import imaging_task, settings
 
