@@ -1,5 +1,9 @@
 
-from nanosurf.lib.devices import i2c 
+"""Copyright (C) Nanosurf AG - All Rights Reserved (2021)
+License - MIT"""
+
+
+import nanosurf.lib.devices.i2c.bus_master as i2c 
 
 class Chip_PCA9534(i2c.I2CChip):
     """ 8bit GPIO chip"""
