@@ -11,7 +11,7 @@ from enum import IntEnum
 import typing
 from PySide2 import QtGui, QtWidgets
 from PySide2.QtCore import Qt, Signal
-from nanosurf.lib.gui.nsf_widgets_common import g_nsf_label_widget_content_margins, g_nsf_label_widget_spacing
+from nanosurf.lib.gui.nsf_widgets_common import LabelWidgetSize, WidgetLayout
 
 class NSFComboEntry():
     id: int
@@ -53,9 +53,9 @@ class NSFComboBox(QtWidgets.QWidget):
     """ Custom Qt Widget to show text in a edit with a descriptive label. """
     value_changed_event = Signal(str)
 
-    def __init__(self, entries: list[NSFComboEntry] = [], label_str = "", *args, **kwargs):
+    def __init__(self, entries: list[NSFComboEntry] = [], label_str = "", layout:WidgetLayout = WidgetLayout.Vertical, text_align_label:Qt.AlignmentFlag=Qt.AlignmentFlag.AlignLeft, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self._setup_widgets(label_str)
+        self._setup_widgets(label_str, layout, text_align_label)
         self.comp_entries = entries
         self.define_entries(self.comp_entries)
         self._combo.value_changed_event.connect(self._on_value_changed)
@@ -89,18 +89,27 @@ class NSFComboBox(QtWidgets.QWidget):
 
     # internal ----------------------------------------------------
     
-    def _setup_widgets(self, label_str: str):
-        layout = QtWidgets.QVBoxLayout()
-        layout.setContentsMargins(*g_nsf_label_widget_content_margins)
-        layout.setSpacing(g_nsf_label_widget_spacing) 
+    def _setup_widgets(self, label_str: str, layout:WidgetLayout, text_align_label:Qt.AlignmentFlag):
+        widget_layout = QtWidgets.QGridLayout()
+        widget_layout.setContentsMargins(*LabelWidgetSize.content_margins)
         self._label = QtWidgets.QLabel()
-        self._label.setText(label_str)
-        self._label.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
-        layout.addWidget(self._label, alignment=Qt.AlignBottom)
         self._combo = _ComboboxQt()
-        self._combo.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
-        layout.addWidget(self._combo)
-        self.setLayout(layout)
+        self._label.setText(label_str)
+        if layout == WidgetLayout.Horizontal:
+            widget_layout.setSpacing(LabelWidgetSize.spacing_horizontal) 
+            widget_layout.setColumnStretch(0,1)
+            widget_layout.setColumnStretch(1,2)
+            self._label.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
+            self._combo.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
+            widget_layout.addWidget(self._label, 0,0, alignment=Qt.AlignVCenter | text_align_label)
+            widget_layout.addWidget(self._combo, 0,1, alignment=Qt.AlignVCenter)        
+        else:
+            widget_layout.setSpacing(LabelWidgetSize.spacing_vertical) 
+            self._label.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
+            self._combo.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
+            widget_layout.addWidget(self._label, 0,0, alignment=Qt.AlignTop    | text_align_label)
+            widget_layout.addWidget(self._combo, 1,0, alignment=Qt.AlignBottom )
+        self.setLayout(widget_layout)
 
     def _on_value_changed(self):
         self.value_changed_event.emit(self.value())
