@@ -282,11 +282,7 @@ class StudioScriptContext(StudioScriptInterface):
         ok = False   
         self._last_error = ""
         if lupa.lua_type(arg) != "table":
-            if type(arg) == str:
-                arg = self._args_to_string(arg)
-            elif type(arg) == list:
-                arg:str = str(arg)
-                arg = '{' + arg.removeprefix('[').removesuffix(']') + '}'
+            arg = self._args_to_string(arg)
             ok, _ = self._process_command(f"{lua_str}={arg}; return 0")
         else:
             ok = False
@@ -368,6 +364,8 @@ class StudioScriptContext(StudioScriptInterface):
         for a in args:
             if type(a) == str:
                 res += "'" + self._python_to_lua_str(a) + "',"
+            elif type(a) == bool:
+                res += str(a).lower()
             elif type(a) == list:
                 res += '{' + str(a).removeprefix('[').removesuffix(']') + '},'
             elif isinstance(a, studio_wrapper.CmdTreeNode):
