@@ -1,5 +1,6 @@
 # studio node base class.py
 
+from ast import If
 import os
 import pathlib
 import enum
@@ -78,7 +79,8 @@ class CmdTreeProp(CmdTreeNode):
         return super().__repr__()
 
 class CmdTreeCompiler():
-    def __init__(self):
+    def __init__(self, parent : 'StudioScriptContext'):
+        self.parent_context = parent
         self._file_content = [""]
         self._last_error = ""
         self.my_own_path = pathlib.Path(os.path.dirname(os.path.abspath(__file__)))
@@ -186,13 +188,23 @@ class CmdTreeCompiler():
             class_name =  "num_" + class_name
         return class_name
 
-    def _get_studio_property_elements(self, prop_table) -> dict[str, str]:
+    def _get_correct_number_type(self, lua_tree_name : str,  item_name : str) -> LuaType:
+        type_str = self.parent_context.lua_number_type_str(f"{lua_tree_name}.{item_name}")
+        if type_str == "float":
+            return LuaType.Float
+        elif type_str == "integer":
+            return LuaType.Int
+        return LuaType.Nil        
+
+    def _get_studio_property_elements(self, prop_table, lua_tree_name : str) -> dict[str, str]:
         """ Extract from property style lua_table a list of all property names and their types
             returns a dict with key:name, val:type
         """
         property_elements: dict[str, str] = {}
         for item_name, item_value in prop_table.items():
             item_type = get_lua_type(item_value)
+            if item_type == LuaType.Int:
+                item_type = self._get_correct_number_type(lua_tree_name, item_name)
             if item_type != LuaType.Function:
                 property_elements[item_name] = get_lua_type_str(item_type)
         return property_elements
@@ -253,7 +265,7 @@ class CmdTreeCompiler():
 
         if self._is_table_a_studio_property(table):
             class_list.append(f"class {class_name}(wrap.CmdTreeProp):\n")
-            prop_elements = self._get_studio_property_elements(table)
+            prop_elements = self._get_studio_property_elements(table, lua_tree_name)
 
             is_prop_enum_type = self._is_enum_property(prop_elements)
             if is_prop_enum_type:
@@ -316,6 +328,8 @@ class CmdTreeCompiler():
                         class_list.append(f"        return self._context.call('{lua_tree_name}.{item_name}', *args)\n")
                         class_list.append(f"\n")
                 elif (item_type != LuaType.Nil) and (item_type != LuaType.Table) and type(item_name) == str:
+                    if item_type == LuaType.Int:
+                        item_type = self._get_correct_number_type(lua_tree_name, item_name)
                     type_str = get_lua_type_str(item_type)
                     class_list.append(f"    @property\n")
                     class_list.append(f"    def {item_name}(self) -> {type_str}:\n")
