@@ -513,7 +513,7 @@ class FrequencySweep():
             InputSource.MainLockIn_Amplitude: self._analyzer.Input.Analyzer1_Amplitude,
             InputSource.MainPLL_FreqShift: self._analyzer.Input.Analyzer1_CtrlDeltaF,
             InputSource.ZControllerOut: self._analyzer.Input.CtrlZ_Out,
-            InputSource.InDetectorSum : self._analyzer.Input.self._analyzer.Input.InDetectorSum,
+            InputSource.InDetectorSum : self._analyzer.Input.InDetectorSum,
             InputSource.In6 : self._analyzer.Input.In6,
             InputSource.CtrlX_Out : self._analyzer.Input.CtrlX_Out,
             InputSource.CtrlY_Out : self._analyzer.Input.CtrlY_Out,
